@@ -29,11 +29,11 @@
 #include <qapplication.h>
 //#define NO_STATIC_COLORS
 #include "globaldefs.h"
-#include <qstrlist.h>
-#include <qdict.h>
+#include <q3strlist.h>
+#include <q3dict.h>
 #include <qfile.h>
-#include <qtextstream.h>
-#include <qcleanuphandler.h>
+#include <q3textstream.h>
+#include <q3cleanuphandler.h>
 
 #include <qfeatures.h>
 
@@ -46,11 +46,11 @@ const int dbsize = 300;
 const int dbcustom = 200;
 const int dbdictsize = 211;
 static WidgetDatabaseRecord* widget_db[ dbsize ];
-static QDict<int> *className2Id = 0;
+static Q3Dict<int> *className2Id = 0;
 static int dbcount  = 0;
 static int dbcustomcount = 200;
-static QStrList *wGroups;
-static QStrList *invisibleGroups;
+static Q3StrList *wGroups;
+static Q3StrList *invisibleGroups;
 static bool whatsThisLoaded = false;
 #ifndef KOMMANDER
 static QPluginManager<WidgetInterface> *widgetPluginManager = 0;
@@ -59,20 +59,20 @@ static bool plugins_set_up = false;
 static bool was_in_setup = false;
 
 #ifndef KOMMANDER
-QCleanupHandler<QPluginManager<WidgetInterface> > cleanup_manager;
+Q3CleanupHandler<QPluginManager<WidgetInterface> > cleanup_manager;
 #endif
 
 WidgetDatabaseRecord::WidgetDatabaseRecord()
 {
     isForm = false;
     isContainer = false;
-    iconSet = 0;
+    icon = 0;
     nameCounter = 0;
 }
 
 WidgetDatabaseRecord::~WidgetDatabaseRecord()
 {
-    delete iconSet;
+    delete icon;
 }
 
 
@@ -81,7 +81,7 @@ WidgetDatabaseRecord::~WidgetDatabaseRecord()
   \brief The WidgetDatabase class holds information about widgets
 
   The WidgetDatabase holds information about widgets like toolTip(),
-  iconName(), ... It works Id-based, so all access functions take the
+  iconSet(), ... It works Id-based, so all access functions take the
   widget id as parameter. To get the id for a widget (classname), use
   idFromClassName().
 
@@ -122,46 +122,46 @@ void WidgetDatabase::setupDataBase( int id )
     return;
 #endif
 
-  wGroups = new QStrList;
-  invisibleGroups = new QStrList;
+  wGroups = new Q3StrList;
+  invisibleGroups = new Q3StrList;
   invisibleGroups->append("Forms");
   invisibleGroups->append("Temp");
-  className2Id = new QDict < int >(dbdictsize);
+  className2Id = new Q3Dict < int >(dbdictsize);
   className2Id->setAutoDelete(true);
 
   WidgetDatabaseRecord *r = 0;
 
   /* Designer widgets */
   r = new WidgetDatabaseRecord;
-  r->iconName = "pushbutton.xpm";
+  r->iconSet = "pushbutton.xpm";
   r->name = "QPushButton";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Push Button");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "toolbutton.xpm";
+  r->iconSet = "toolbutton.xpm";
   r->name = "QToolButton";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Tool Button");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "radiobutton.xpm";
+  r->iconSet = "radiobutton.xpm";
   r->name = "QRadioButton";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Radio Button");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "checkbox.xpm";
+  r->iconSet = "checkbox.xpm";
   r->name = "QCheckBox";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Check Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "groupbox.xpm";
+  r->iconSet = "groupbox.xpm";
   r->name = "QGroupBox";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Group Box");
@@ -169,7 +169,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "buttongroup.xpm";
+  r->iconSet = "buttongroup.xpm";
   r->name = "QButtonGroup";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Button Group");
@@ -177,7 +177,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "frame.xpm";
+  r->iconSet = "frame.xpm";
   r->name = "QFrame";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Frame");
@@ -185,7 +185,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "tabwidget.xpm";
+  r->iconSet = "tabwidget.xpm";
   r->name = "QTabWidget";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Tabwidget");
@@ -193,14 +193,14 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "listbox.xpm";
+  r->iconSet = "listbox.xpm";
   r->name = "QListBox";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("List Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "listview.xpm";
+  r->iconSet = "listview.xpm";
   r->name = "QListView";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("List View");
@@ -208,7 +208,7 @@ void WidgetDatabase::setupDataBase( int id )
 
 #if !defined(QT_NO_ICONVIEW) || defined(UIC)
   r = new WidgetDatabaseRecord;
-  r->iconName = "iconview.xpm";
+  r->iconSet = "iconview.xpm";
   r->name = "QIconView";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("Icon View");
@@ -217,7 +217,7 @@ void WidgetDatabase::setupDataBase( int id )
 
 #if !defined(QT_NO_TABLE)
   r = new WidgetDatabaseRecord;
-  r->iconName = "table.xpm";
+  r->iconSet = "table.xpm";
   r->name = "QTable";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("Table");
@@ -226,7 +226,7 @@ void WidgetDatabase::setupDataBase( int id )
 
 #if !defined(QT_NO_SQL)
   r = new WidgetDatabaseRecord;
-  r->iconName = "datatable.xpm";
+  r->iconSet = "datatable.xpm";
   r->includeFile = "qdatatable.h";
   r->name = "QDataTable";
   r->group = widgetGroup("Database");
@@ -235,21 +235,21 @@ void WidgetDatabase::setupDataBase( int id )
 #endif
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "lineedit.xpm";
+  r->iconSet = "lineedit.xpm";
   r->name = "QLineEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Line Edit");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "spinbox.xpm";
+  r->iconSet = "spinbox.xpm";
   r->name = "QSpinBox";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Spin Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "dateedit.xpm";
+  r->iconSet = "dateedit.xpm";
   r->name = "QDateEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Date Edit");
@@ -257,7 +257,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "timeedit.xpm";
+  r->iconSet = "timeedit.xpm";
   r->name = "QTimeEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Time Edit");
@@ -265,7 +265,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "datetimeedit.xpm";
+  r->iconSet = "datetimeedit.xpm";
   r->name = "QDateTimeEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Date-Time Edit");
@@ -273,84 +273,84 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "multilineedit.xpm";
+  r->iconSet = "multilineedit.xpm";
   r->name = "QMultiLineEdit";
   r->group = widgetGroup("Temp");
   r->toolTip = i18n("Multi Line Edit");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "richtextedit.xpm";
+  r->iconSet = "richtextedit.xpm";
   r->name = "QTextEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Rich Text Edit");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "combobox.xpm";
+  r->iconSet = "combobox.xpm";
   r->name = "QComboBox";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Combo Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "slider.xpm";
+  r->iconSet = "slider.xpm";
   r->name = "QSlider";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Slider");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "scrollbar.xpm";
+  r->iconSet = "scrollbar.xpm";
   r->name = "QScrollBar";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Scrollbar");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "dial.xpm";
+  r->iconSet = "dial.xpm";
   r->name = "QDial";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Dial");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "label.xpm";
+  r->iconSet = "label.xpm";
   r->name = "QLabel";
   r->group = widgetGroup("Temp");
   r->toolTip = i18n("Label");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "lcdnumber.xpm";
+  r->iconSet = "lcdnumber.xpm";
   r->name = "QLCDNumber";
   r->group = widgetGroup("Display");
   r->toolTip = i18n("LCD Number");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "progress.xpm";
+  r->iconSet = "progress.xpm";
   r->name = "QProgressBar";
   r->group = widgetGroup("Display");
   r->toolTip = i18n("Progress Bar");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "textview.xpm";
+  r->iconSet = "textview.xpm";
   r->name = "QTextView";
   r->group = widgetGroup("Temp");
   r->toolTip = i18n("Text View");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "textbrowser.xpm";
+  r->iconSet = "textbrowser.xpm";
   r->name = "QTextBrowser";
   r->group = widgetGroup("Display");
   r->toolTip = i18n("Text Browser");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "spacer.xpm";
+  r->iconSet = "spacer.xpm";
   r->name = "Spacer";
   r->group = widgetGroup("Temp");
   r->toolTip = i18n("Spacer");
@@ -397,28 +397,28 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "tabwidget.xpm";
+  r->iconSet = "tabwidget.xpm";
   r->name = "QDesignerTabWidget";
   r->group = widgetGroup("Temp");
   r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "tabwidget.xpm";
+  r->iconSet = "tabwidget.xpm";
   r->name = "QDesignerWidget";
   r->group = widgetGroup("Temp");
   r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "tabwidget.xpm";
+  r->iconSet = "tabwidget.xpm";
   r->name = "QDesignerDialog";
   r->group = widgetGroup("Temp");
   r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "";
+  r->iconSet = "";
   r->name = "QMainWindow";
   r->includeFile = "qmainwindow.h";
   r->group = widgetGroup("Temp");
@@ -431,7 +431,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->includeFile = "qdatabrowser.h";
   r->group = widgetGroup("Database");
   r->toolTip = "Data Browser";
-  r->iconName = "databrowser.xpm";
+  r->iconSet = "databrowser.xpm";
   r->isContainer = true;
   append(r);
 
@@ -440,7 +440,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->includeFile = "qdataview.h";
   r->group = widgetGroup("Database");
   r->toolTip = "Data View";
-  r->iconName = "dataview.xpm";
+  r->iconSet = "dataview.xpm";
   r->isContainer = true;
   append(r);
 #endif
@@ -479,16 +479,11 @@ void WidgetDatabase::setupDataBase( int id )
   r->isContainer = true;
   append(r);
 
-  r = new WidgetDatabaseRecord;
-  r->name = "EditorToolBox";
-  r->group = widgetGroup("Temp");
-  r->isContainer = true;
-  append(r);
 
 
   /* Kommandr widgets */
   r = new WidgetDatabaseRecord;
-  r->iconName = "label.xpm";
+  r->iconSet = "label.xpm";
   r->name = "Label";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("Text Label");
@@ -496,7 +491,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "pixlabel.xpm";
+  r->iconSet = "pixlabel.xpm";
   r->name = "PixmapLabel";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("Pixmap Label");
@@ -504,7 +499,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "lineedit.xpm";
+  r->iconSet = "lineedit.xpm";
   r->name = "LineEdit";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A line edit");
@@ -512,27 +507,27 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->name = "TextEdit";
-  r->iconName = "textedit.png";
+  r->iconSet = "textedit.png";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A rich text edit");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "TextBrowser";
-  r->iconName = "textbrowser.png";
+  r->iconSet = "textbrowser.png";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("Text Browser");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "listbox.xpm";
+  r->iconSet = "listbox.xpm";
   r->name = "ListBox";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("List Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "combobox.xpm";
+  r->iconSet = "combobox.xpm";
   r->name = "ComboBox";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A combo box");
@@ -540,27 +535,27 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->name = "TreeWidget";
-  r->iconName = "listview.png";
+  r->iconSet = "listview.png";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A tree widget");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "Table";
-  r->iconName = "table.xmp";
+  r->iconSet = "table.xmp";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A table widget");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "pushbutton.xpm";
+  r->iconSet = "pushbutton.xpm";
   r->name = "ExecButton";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A button that when clicked, execute a command");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "closebutton.png";
+  r->iconSet = "closebutton.png";
   r->name = "CloseButton";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A button that closes the dialog it is in");
@@ -568,34 +563,34 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->name = "Konsole";
-  r->iconName = "konsole.png";
+  r->iconSet = "konsole.png";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A listbox showing output of a script");
   append(r);
   
   r = new WidgetDatabaseRecord;
   r->name = "FileSelector";
-  r->iconName = "lineedit.xpm";
+  r->iconSet = "lineedit.xpm";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A widget made up of a line edit and push button, for selecting files and folders");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "checkbox.xpm";
+  r->iconSet = "checkbox.xpm";
   r->name = "CheckBox";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A check box");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "radiobutton.xpm";
+  r->iconSet = "radiobutton.xpm";
   r->name = "RadioButton";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A radio button");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "buttongroup.xpm";
+  r->iconSet = "buttongroup.xpm";
   r->name = "ButtonGroup";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A widget for grouping buttons together");
@@ -603,7 +598,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "groupbox.xpm";
+  r->iconSet = "groupbox.xpm";
   r->name = "GroupBox";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A widget for grouping other widgets together");
@@ -611,24 +606,15 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->iconName = "tabwidget.xpm";
+  r->iconSet = "tabwidget.xpm";
   r->name = "TabWidget";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A widget with tabs");
   r->isContainer = true;
   append(r);
 
-
-//   r = new WidgetDatabaseRecord;
-//   r->iconName = "";
-//   r->name = "ToolBox";
-//   r->group = widgetGroup("Kommander");
-//   r->toolTip = "";
-//   r->isContainer = true;
-//   append(r);
-
   r = new WidgetDatabaseRecord;
-  r->iconName = "spinbox.xpm";
+  r->iconSet = "spinbox.xpm";
   r->name = "SpinBoxInt";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A spin box");
@@ -636,52 +622,45 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->name = "Slider";
-  r->iconName = "slider.png";
+  r->iconSet = "slider.png";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("Slider");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "RichTextEditor";
-  r->iconName = "richtextedit.xpm";
+  r->iconSet = "richtextedit.xpm";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A small rich text editor");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "StatusBar";
-  r->iconName = "statusbar.png";
+  r->iconSet = "statusbar.png";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A status bar");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "ProgressBar";
-  r->iconName = "progress.png";
+  r->iconSet = "progress.png";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A progress bar");
   append(r);
   
   r = new WidgetDatabaseRecord;
   r->name = "ScriptObject";
-  r->iconName = "shellscript.png";
+  r->iconSet = "exec.png";
   r->group = widgetGroup( "Kommander" );
   r->toolTip = i18n("A hidden script container");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "Timer";
-  r->iconName = "timer.png";
+  r->iconSet = "timer.png";
   r->group = widgetGroup( "Kommander" );
   r->toolTip = i18n("A timer for running scripts periodically");
   append(r);
- 
- r = new WidgetDatabaseRecord;
-  r->iconName = "datepicker.xpm";
-  r->name = "DatePicker";
-  r->group = widgetGroup("Kommander");
-  r->toolTip = i18n("A date selection widget");
-  append(r);
 
 #ifndef UIC
   setupPlugins();
@@ -707,7 +686,6 @@ void WidgetDatabase::setupPlugins()
       grp = "Kommander";
     r->group = widgetGroup(grp);
     r->toolTip = (*it).toolTip;
-    r->iconSet = (*it).iconSet;
     r->whatsThis = (*it).whatsThis;
     r->isContainer = (*it).isContainer;
     r->name = it.key();
@@ -739,19 +717,19 @@ int WidgetDatabase::startCustom()
   Returns the iconset which represents the class registered as \a id.
 */
 
-QIconSet WidgetDatabase::iconSet( int id )
+QIcon WidgetDatabase::iconSet( int id )
 {
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	   return QIconSet();
+	return QIcon();
 #if !defined(UIC) && !defined(RESOURCE)
-    if ( !r->iconSet )
-	   r->iconSet = new QIconSet( PixmapChooser::loadPixmap( r->iconName, PixmapChooser::Small ),
-				PixmapChooser::loadPixmap( r->iconName, PixmapChooser::Large ) );
-    return *r->iconSet;
+    if ( !r->icon )
+	r->icon = new QIcon( PixmapChooser::loadPixmap( r->iconSet, PixmapChooser::Small ),
+				PixmapChooser::loadPixmap( r->iconSet, PixmapChooser::Large ) );
+    return *r->icon;
 #else
-    return QIconSet();
+    return QIcon();
 #endif
 }
 
@@ -764,7 +742,7 @@ QString WidgetDatabase::className( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return QString::null;
+	return QString();
     return r->name;
 }
 
@@ -777,7 +755,7 @@ QString WidgetDatabase::group( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return QString::null;
+	return QString();
     return r->group;
 }
 
@@ -790,7 +768,7 @@ QString WidgetDatabase::toolTip( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return QString::null;
+	return QString();
     return r->toolTip;
 }
 
@@ -803,7 +781,7 @@ QString WidgetDatabase::whatsThis( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return QString::null;
+	return QString();
     return r->whatsThis;
 }
 
@@ -816,9 +794,9 @@ QString WidgetDatabase::includeFile( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return QString::null;
+	return QString();
     if ( r->includeFile.isNull() )
-	return r->name.lower() + ".h";
+	return r->name.toLower() + ".h";
     return r->includeFile;
 }
 
@@ -904,7 +882,7 @@ void WidgetDatabase::insert( int index, WidgetDatabaseRecord *r )
     widget_db[ index ] = r;
     className2Id->insert( r->name, new int( index ) );
     if ( index < dbcustom )
-	dbcount = QMAX( dbcount, index );
+	dbcount = qMax( dbcount, index );
 }
 
 void WidgetDatabase::append( WidgetDatabaseRecord *r )
@@ -945,7 +923,7 @@ QString WidgetDatabase::widgetGroup( int i )
     setupDataBase( -1 );
     if ( i >= 0 && i < (int)wGroups->count() )
 	return wGroups->at( i );
-    return QString::null;
+    return QString();
 }
 
 int WidgetDatabase::numWidgetGroups()
@@ -982,9 +960,9 @@ void WidgetDatabase::loadWhatsThis( const QString &docPath )
 {
     QString whatsthisFile = docPath + "/whatsthis";
     QFile f( whatsthisFile );
-    if ( !f.open( IO_ReadOnly ) )
+    if ( !f.open( QIODevice::ReadOnly ) )
 	return;
-    QTextStream ts( &f );
+    Q3TextStream ts( &f );
     while ( !ts.atEnd() ) {
 	QString s = ts.readLine();
 	QStringList l = QStringList::split( " | ", s );
