@@ -159,7 +159,7 @@ int xslDbgShellOptions(void)
                         }
                 }
             }else {
-                qWarning("%s option not found %s", __PRETTY_FUNCTION__,
+                qWarning("xslDbgShellOptions option not found %s",
                         optionName.toLatin1().constData());
             }
         }
